@@ -4,9 +4,8 @@ package T7AttrLazyBuild::TestPackage;
 use strict;
 use warnings;
 use Moose;
-use namespace::autoclean;
-
 use MooseX::Has::Sugar;
+use namespace::clean -except => 'meta';
 
 has roattr => ( isa => 'Str', is => 'ro', lazy_build, );
 
